#include <iostream>
#include <algorithm>
#include <vector>
#include <set>
#include <map>
using namespace std;

struct op;

struct op {
    char muv;
    op* lhs;
    op* rhs;
    op(char amuv, op* al, op* ar): muv(amuv), lhs(al), rhs(ar) {};
};

void print(op* exp) {
    if(exp == nullptr) return;
    cout << exp->muv;
    cout << '(';
    print(exp->lhs);
    cout << ',';
    print(exp->rhs);
    cout << ')';
}

op* make_op(string s) {
    if(s[0] == '(') {
        int p = 0;
        int i = 1;
        do {
            if(s[i] == '(') {
                ++p;
            }
            if(s[i] == ')') {
                --p;
            }
            ++i;
        } while(p > 0);
        char muv = s[i];
        string ls = s.substr(1, i-1);
        string rs = s.substr(i+1, s.length() - i - 2);
        op* lhs = make_op(ls);
        op* rhs = make_op(rs);
        return new op(muv, lhs, rhs);
    }
    else return new op(s[0], nullptr, nullptr);
};

set<char> all_var(op* exp) {
    if(('a' <= exp->muv) && (exp->muv <= 'z')) {
        return set<char>({exp->muv});
    } else {
        set<char> l = all_var(exp->lhs);
        set<char> r = all_var(exp->rhs);
        r.insert(l.begin(), l.end());
        return r;
    }
}

int eval(op* exp, map<char, int> var) {
    switch(exp->muv) {
    case '+':
        return eval(exp->lhs, var) + eval(exp->rhs, var);
    case '-':
        return eval(exp->lhs, var) - eval(exp->rhs, var);
    case '*':
        return eval(exp->lhs, var) * eval(exp->rhs, var);
    default:
        return var[exp->muv];
    }
}

void delete_op(op* exp) {
    if(exp->lhs != nullptr) {
        delete_op(exp->lhs);
    }
    if(exp->rhs != nullptr) {
        delete_op(exp->rhs);
    }
    delete exp;
}

int main()
{
ios::sync_with_stdio(0);
while(true) {
    int n;
    cin >> n;
    vector<int> v(n);
    for(int &x : v) {
        cin >> x;
    }
    int m;
    cin >> m;
    if((0 == n) && (0 == m)) break;
    string ex;
    cin >> ex;

    op* muv = make_op(ex);
    set<char> av = all_var(muv);
    sort(v.begin(), v.end());
    do{
        map<char, int> mci;
        int p = 0;
        for(char c : av) {
            mci[c] = v[p];
            ++p;
        }
        int res = eval(muv, mci);
        if(res == m) {
            cout << "YES" << endl;
            goto cont;
        }
    } while(next_permutation(v.begin(), v.end()));
    cout << "NO" << endl;
    cont: delete_op(muv);
}
return 0;
}
